Index: chrome/browser/themes/browser_theme_pack.cc |
diff --git a/chrome/browser/themes/browser_theme_pack.cc b/chrome/browser/themes/browser_theme_pack.cc |
index 66d2c63b0ca728c11c23791d7d5e9e43f29ae0f6..58e771e6eb34fa75ffd0419b54778123924ce2a4 100644 |
--- a/chrome/browser/themes/browser_theme_pack.cc |
+++ b/chrome/browser/themes/browser_theme_pack.cc |
@@ -49,7 +49,7 @@ namespace { |
// theme packs that aren't int-equal to this. Increment this number if you |
// change default theme assets or if you need themes to recreate their generated |
// images (which are cached). |
-const int kThemePackVersion = 42; |
+const int kThemePackVersion = 43; |
// IDs that are in the DataPack won't clash with the positive integer |
// uint16_t. kHeaderID should always have the maximum value because we want the |
@@ -791,9 +791,12 @@ bool BrowserThemePack::GetColor(int id, SkColor* color) const { |
if (colors_[i].id == id) { |
*color = colors_[i].color; |
// The theme provider is intentionally made to ignore alpha for toolbar |
- // color, as we don't want to allow transparent toolbars. |
- if (id == ThemeProperties::COLOR_TOOLBAR) |
+ // color, as we don't want to allow transparent toolbars. Same for the |
+ // ntp background color. |
+ if (id == ThemeProperties::COLOR_TOOLBAR || |
+ id == ThemeProperties::COLOR_NTP_BACKGROUND) { |
*color = SkColorSetA(*color, SK_AlphaOPAQUE); |
+ } |
return true; |
} |
} |